aboutsummaryrefslogtreecommitdiff
path: root/engines/gob/init_v3.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'engines/gob/init_v3.cpp')
-rw-r--r--engines/gob/init_v3.cpp7
1 files changed, 4 insertions, 3 deletions
diff --git a/engines/gob/init_v3.cpp b/engines/gob/init_v3.cpp
index 4a2379bad0..b3816c10e9 100644
--- a/engines/gob/init_v3.cpp
+++ b/engines/gob/init_v3.cpp
@@ -39,10 +39,11 @@ Init_v3::~Init_v3() {
}
void Init_v3::updateConfig() {
// In the CD version of Goblins3, some texts are flagged 'subtitles'
// incorrectly and therefore should be displayed in all cases.
// The first obvious example is just after Death level.
- if ((_vm->getGameType() == kGameTypeGob3) && _vm->isCD())
+ if ((_vm->getGameType() == kGameTypeGob3) &&
+ (_vm->isCD() || (_vm->getPlatform() == Common::kPlatformWindows)))
_vm->_global->_doSubtitles = true;
}
@@ -39,10 +39,11 @@ Init_v3::~Init_v3() {
}
void Init_v3::updateConfig() {
-// In the CD version of Goblins3, some texts are flagged 'subtitles'
-// incorrectly and therefore should be displayed in all cases.
+// In the CD and Windows version of Goblins3, some texts are flagged
+// 'subtitles' incorrectly and therefore should be displayed in all cases.
// The first obvious example is just after Death level.